synthetic_aia_mia.generator package — src documentation

# synthetic_aia_mia.generator package

## Submodules

## synthetic_aia_mia.generator.adult module

synthetic_aia_mia.generator.adult.ctgan(dadata)

  Generate synthetic data using ctgan trained on input data.

  Parameters:

    data (fetch_data.Dataset) – Real dataset used to train ctgan.

  Returns:

    Synthetic dataset.

  Return type:

    fetch_data.Dataset

## synthetic_aia_mia.generator.example module

Show how to import the fetch_data package. If the dataset isn’t accessible, it will be downloaded using folktables API.

synthetic_aia_mia.generator.example.evaluate(synth_data)

  Evaluate synthetic data.

synthetic_aia_mia.generator.example.generator(real_data)

  Return a trained generator.

## Module contents

Generate synthetic data and evaluate their quality.

synthetic_aia_mia.generator.identity(x)

  Identity function. Return the input dataset.

  Parameters:

    x (fetch_data.Dataset) – Dataset.

  Returns:

    Return the input x as is.

  Return type:

    fetch_data.Dataset

synthetic_aia_mia.generator.vae(x)

  Place holder for vae. At the moment, return the input dataset.

  Parameters:

    x (pandas.dataframe) – Dataset.